pub fn all_true(
b: &CircuitBuilder,
booleans: impl IntoIterator<Item = Wire>,
) -> WireExpand description
Check that all boolean wires in an iterable are simultaneously true.
pub fn all_true(
b: &CircuitBuilder,
booleans: impl IntoIterator<Item = Wire>,
) -> WireCheck that all boolean wires in an iterable are simultaneously true.