pack_bytes_into_wires_le

Function pack_bytes_into_wires_le 

pub fn pack_bytes_into_wires_le(
    w: &mut WitnessFiller<'_>,
    wires: &[Wire],
    bytes: &[u8],
)
Populate the given wires from bytes using little-endian packed 64-bit words.

If bytes is not a multiple of 8, the last word is zero-padded.

If there are more wires than needed to hold all bytes, the remaining wires are filled with Word::ZERO.

Panics

  • If bytes.len() exceeds wires.len() * 8